'use strict';

var _interopRequireDefault = require('@babel/runtime/helpers/interopRequireDefault');

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.checkA11y = exports.configureA11y = void 0;

var _global = require('global');

var _axeCore = _interopRequireDefault(require('axe-core'));

var _addons = _interopRequireDefault(require('@storybook/addons'));

var _coreEvents = _interopRequireDefault(require('@storybook/core-events'));

var _clientLogger = require('@storybook/client-logger');

var _shared = require('./shared');

var axeOptions = {};

var configureA11y = function configureA11y() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  axeOptions = options;
};

exports.configureA11y = configureA11y;

var alreadyRunning = false;

var runA11yCheck = function runA11yCheck() {
  if (alreadyRunning) {
    return;
  }

  alreadyRunning = true;

  var channel = _addons.default.getChannel();

  var wrapper = _global.document.getElementById('root');

  _axeCore.default.reset();

  _axeCore.default.configure(axeOptions);

  _axeCore.default
    .run(wrapper)
    .then(function(results) {
      alreadyRunning = false;
      return channel.emit(_shared.CHECK_EVENT_ID, results);
    }, _clientLogger.logger.error)
    .catch(function() {
      alreadyRunning = false;
    });
};

var a11ySubscription = function a11ySubscription() {
  var channel = _addons.default.getChannel();

  channel.on(_shared.REQUEST_CHECK_EVENT_ID, runA11yCheck);
  return function() {
    channel.removeListener(_shared.REQUEST_CHECK_EVENT_ID, runA11yCheck);
  };
};

var checkA11y = function checkA11y(story) {
  _addons.default.getChannel().emit(_coreEvents.default.REGISTER_SUBSCRIPTION, a11ySubscription);

  return story();
};

exports.checkA11y = checkA11y;
