"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var addon_knobs_1 = require("@storybook/addon-knobs");
var addon_actions_1 = require("@storybook/addon-actions");
var metadata_1 = require("../../server/analysis/metadata");
/**
 * Auto-props default values.
 */
exports.PROP_DEFAULTS = {
    text: "",
    number: 1,
    boolean: false,
    array: [],
    date: new Date(),
    action: function (args) { return args; }
};
function getKnobForProperty(prop, defaults) {
    switch (prop.type) {
        case "string":
            return addon_knobs_1.text(prop.name, evalDefault(prop.defaultValue) || defaults.text);
        case "number":
            return addon_knobs_1.number(prop.name, evalDefault(prop.defaultValue) || defaults.number);
        case "boolean":
            return addon_knobs_1.boolean(prop.name, evalDefault(prop.defaultValue) || defaults.boolean);
        case "Date":
            return addon_knobs_1.date(prop.name, evalDefault(prop.defaultValue) || defaults.date);
        default:
            if (prop.type.endsWith("[]")) {
                return addon_knobs_1.array(prop.name, evalDefault(prop.defaultValue) || defaults.array);
            }
            return addon_knobs_1.object(prop.name, evalDefault("(" + prop.defaultValue + ")") || {});
    }
    function evalDefault(value) {
        if (!value) {
            return null;
        }
        try {
            return eval(value);
        }
        catch (_a) {
            return null;
        }
    }
}
/**
 * Automatically generates props based on Angular and TypeScript metadata from class.
 * @param component Angular component class.
 * @param manualProps Manual props - these will override any auto-generated props.
 * @param defaults Defaults for auto-generated props.
 */
function astProps(component, manualProps, defaults) {
    if (manualProps === void 0) { manualProps = {}; }
    if (defaults === void 0) { defaults = {}; }
    var metadata = metadata_1.asMeta(component);
    if (!metadata) {
        return manualProps;
    }
    defaults = __assign({}, exports.PROP_DEFAULTS, defaults);
    var props = Object.assign({}, manualProps);
    var decoratedLogger = addon_actions_1.decorateAction([defaults.action]);
    metadata.inputs.forEach(function (prop) { return !(prop.name in props) && (props[prop.name] = getKnobForProperty(prop, defaults)); });
    metadata.outputs.forEach(function (prop) { return !(prop.name in props) && (props[prop.name] = decoratedLogger(prop.name)); });
    return props;
}
exports.astProps = astProps;
