/// <reference types="node" />
import { StoryApi } from "../types";
/**
 * Creates a generic story.
 * @param kind story kind. Supports hierarchical separator `:`.
 * @param moduleRef Module reference for HMR.
 */
export declare function storiesOf(kind: string, moduleRef: NodeModule): StoryApi;
/**
 * Creates a story for *style*.
 * This represents the global theme of application.
 * For example: colors, fonts, mixins, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
export declare function storiesOfStyle(name: string, moduleRef: NodeModule): StoryApi;
/**
 * Creates a story for *primitive* component.
 * Primitive components are basic building blocks for the UI.
 * For example: icon, button, label, link, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
export declare function storiesOfPrimitive(name: string, moduleRef: NodeModule): StoryApi;
/**
 * Creates a story for *widget* component.
 * Widgets are combined of primitives or other widgets.
 * For example: date picker, modal, table, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
export declare function storiesOfWidget(name: string, moduleRef: NodeModule): StoryApi;
/**
 * Creates a story for *page* component.
 * Pages are combined of primitives or widgets.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
export declare function storiesOfPage(name: string, moduleRef: NodeModule): StoryApi;
