"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_api_1 = require("./core_api");
var api_docs_1 = require("./api-docs");
var props_1 = require("./props");
var metadata_1 = require("../../server/analysis/metadata");
var pipe_usage_1 = require("./components/pipe-usage");
var common_1 = require("./components/common");
/**
 * Creates a generic story.
 * @param kind story kind. Supports hierarchical separator `:`.
 * @param moduleRef Module reference for HMR.
 */
function storiesOf(kind, moduleRef) {
    return new StoryApiBuilder(core_api_1.storiesOf(kind, moduleRef));
}
exports.storiesOf = storiesOf;
/**
 * Creates a story for *style*.
 * This represents the global theme of application.
 * For example: colors, fonts, mixins, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
function storiesOfStyle(name, moduleRef) {
    return register("Styles", name, moduleRef);
}
exports.storiesOfStyle = storiesOfStyle;
/**
 * Creates a story for *primitive* component.
 * Primitive components are basic building blocks for the UI.
 * For example: icon, button, label, link, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
function storiesOfPrimitive(name, moduleRef) {
    return register("Primitives", name, moduleRef);
}
exports.storiesOfPrimitive = storiesOfPrimitive;
/**
 * Creates a story for *widget* component.
 * Widgets are combined of primitives or other widgets.
 * For example: date picker, modal, table, etc.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
function storiesOfWidget(name, moduleRef) {
    return register("Widgets", name, moduleRef);
}
exports.storiesOfWidget = storiesOfWidget;
/**
 * Creates a story for *page* component.
 * Pages are combined of primitives or widgets.
 * @param name story name. All atomic elements are automatically placed under the same group.
 * @param moduleRef Module reference for HMR.
 */
function storiesOfPage(name, moduleRef) {
    return register("Pages", name, moduleRef);
}
exports.storiesOfPage = storiesOfPage;
function register(group, name, moduleRef) {
    return new StoryApiBuilder(core_api_1.storiesOf(group + ":" + name, moduleRef));
}
var StoryApiBuilder = /** @class */ (function () {
    function StoryApiBuilder(_inner) {
        this._inner = _inner;
    }
    StoryApiBuilder.prototype.add = function (name, storyFn, parameters) {
        this._inner.add(name, storyFn, parameters);
        return this;
    };
    StoryApiBuilder.prototype.addApiDocs = function (name, component, config, parameters) {
        if (config === void 0) { config = function () { return ({}); }; }
        this._inner.add(name, function () {
            var _a = config(), _b = _a.template, template = _b === void 0 ? {} : _b, props = _a.props, _c = _a.moduleMetadata, moduleMetadata = _c === void 0 ? {} : _c, _d = _a.styles, styles = _d === void 0 ? [] : _d, background = _a.background;
            var storyData = {
                meta: metadata_1.asMeta(component),
                realType: metadata_1.asType(component),
                annotation: metadata_1.asAnnotated(component),
                props: props_1.astProps(component, props)
            };
            var realTypeImports = [storyData.realType].filter(function (t) { return t; });
            return {
                template: convertTemplate(component, template, background),
                props: storyData.props,
                moduleMetadata: __assign({}, moduleMetadata, { declarations: (moduleMetadata.declarations || realTypeImports).concat([pipe_usage_1.PipeUsage]), providers: (moduleMetadata.providers || realTypeImports).concat([
                        {
                            provide: common_1.StoryDataToken,
                            useValue: storyData
                        }
                    ]) }),
                styles: styles
            };
        }, parameters);
        return this;
    };
    StoryApiBuilder.prototype.addWikiDocs = function (name, text) {
        this._inner.add(name, function () { return ({ template: { beforePreview: text } }); });
        return this;
    };
    StoryApiBuilder.prototype.addDecorator = function (decorator) {
        this._inner.addDecorator(decorator);
        return this;
    };
    return StoryApiBuilder;
}());
function convertTemplate(component, apiDocs, background) {
    return {
        beforePreview: apiDocs.header,
        preview: apiDocs.preview === false
            ? ""
            : api_docs_1.wrapPreview(apiDocs.preview, true, background === "none") ||
                api_docs_1.astPreview(component, apiDocs.previewTransclude),
        afterPreview: (apiDocs.beforeApiDocs || "") +
            (apiDocs.apiDocs === false ? "" : apiDocs.apiDocs || api_docs_1.astApi(component)) +
            (apiDocs.afterApiDocs || "")
    };
}
