"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PREVIEW = "<!-- PREVIEW -->";
var API = "<!-- API -->";
/**
 * Generates API doc template from Markdown string.
 * Add `<!-- PREVIEW -->` to insert the preview and `<!-- API -->` to insert the API docs.
 * @param markdown Markdown string from `*.md` file.
 */
function apiDocsTemplate(markdown) {
    if (!markdown) {
        return {};
    }
    var _a = ngEscape(markdown).split(PREVIEW), header = _a[0], preview = _a[1];
    var template = {};
    template.header = header;
    if (preview) {
        var _b = preview.split(API), beforeApiDocs = _b[0], afterApiDocs = _b[1];
        template.beforeApiDocs = beforeApiDocs;
        template.afterApiDocs = afterApiDocs;
    }
    return template;
}
exports.apiDocsTemplate = apiDocsTemplate;
/**
 * Combines markdown template with Angular template.
 * @param markdown Markdown string from `*.md` file.
 * @param sections Custom sections (defined as `<!-- section_name -->` in `*.md` file).
 * If string is provided, the section markup will be placed after `markdown`.
 */
function markdownTemplate(markdown, sections) {
    if (sections === void 0) { sections = []; }
    if (!markdown) {
        return "";
    }
    var currentText = ngEscape(markdown);
    var currentTemplate = "";
    if (typeof sections === "string") {
        return asMarkdown(currentText) + sections;
    }
    for (var _i = 0, sections_1 = sections; _i < sections_1.length; _i++) {
        var section = sections_1[_i];
        if (!currentText) {
            break;
        }
        var _a = currentText.split("<!-- " + section.key + " -->"), pre = _a[0], post = _a[1];
        currentTemplate += asMarkdown(pre) + section.template;
        currentText = post;
    }
    return currentTemplate + asMarkdown(currentText);
}
exports.markdownTemplate = markdownTemplate;
function ngEscape(markdownSource) {
    return markdownSource.replace(/([\{\}])/g, function (m) { return (m === "{" ? "&#123;" : "&#125;"); });
}
exports.ngEscape = ngEscape;
/**
 * Wraps the template with `<div class="markdown-body"></div>`.
 * @param template Markdown source template.
 */
function asMarkdown(template) {
    return template ? "<div class=\"markdown-body\">" + template + "</div>" : "";
}
exports.asMarkdown = asMarkdown;
