"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_simple_ast_1 = require("ts-simple-ast");
var utils_1 = require("./analysis/utils");
function wrapSource(path, source) {
    return ts_simple_ast_1.createWrappedNode(ts_simple_ast_1.ts.createSourceFile(path, source, ts_simple_ast_1.ScriptTarget.Latest, true, ts_simple_ast_1.ScriptKind.TS));
}
function replaceTriggers(source, triggers) {
    var builder = [];
    var currentIndex = 0;
    var sorted = triggers.sort(function (a, b) { return (a.replacement.start > b.replacement.start ? 1 : -1); });
    for (var _i = 0, sorted_1 = sorted; _i < sorted_1.length; _i++) {
        var _a = sorted_1[_i].replacement, start = _a.start, end = _a.end, text = _a.text;
        builder.push(source.substring(currentIndex, start), text);
        currentIndex = end;
    }
    builder.push(source.substring(currentIndex));
    return builder.join("");
}
function createReader(context) {
    return function (p) {
        try {
            return context.fs.readFileSync(p).toString("utf-8");
        }
        catch (_a) {
            console.warn("[ngx-storybook] Error resolving " + JSON.stringify(p) + ". Make sure you're not using dynamic imports or aliases.");
            return null;
        }
    };
}
function runAnalysis(context, source) {
    var metadata = context["n9ngxstb.plugin"].metadata;
    var reader = createReader(context);
    if (!/\.story\.ts$/.test(context.resourcePath)) {
        if (Object.keys(metadata).some(function (m) { return m.startsWith(context.resourcePath); })) {
            var sourceFile = wrapSource(context.resourcePath, source);
            var triggers_1 = sourceFile.getClasses().map(function (c) { return ({
                key: context.resourcePath + "+" + c.getName(),
                declaration: c,
                filePath: context.resourcePath
            }); });
            loadMetadata(context, triggers_1, reader);
        }
        return source;
    }
    var triggers = utils_1.findTriggers(wrapSource(context.resourcePath, source), reader);
    loadMetadata(context, triggers, reader);
    return replaceTriggers(source, triggers);
}
function loadMetadata(context, triggers, reader) {
    var _a = context["n9ngxstb.plugin"], metadata = _a.metadata, currentRunMetadata = _a.currentRunMetadata, options = _a.options;
    for (var _i = 0, triggers_2 = triggers; _i < triggers_2.length; _i++) {
        var target = triggers_2[_i];
        if (!target.key || currentRunMetadata[target.key]) {
            continue;
        }
        var meta = (currentRunMetadata[target.key] = metadata[target.key] = utils_1.getMetadata(target.declaration, options.markedOptions, reader));
        if (options.gitLinking) {
            meta.gitUrl = target.filePath.replace(options.gitLinking.localGitDir, normalizeGitBlob(options.gitLinking.gitBlobUrl || readEnvGitBlob() || ""));
        }
    }
}
function normalizeGitBlob(url) {
    return url.replace(".git", "").replace(/[\/\\]$/, "");
}
function readEnvGitBlob() {
    return normalizeGitBlob(process.env.STORYBOOK_GIT_ORIGIN || "") + "/blob/" + (process.env
        .STORYBOOK_GIT_BRANCH || "");
}
module.exports = function (source) {
    var done = this.async();
    var that = this;
    setTimeout(function () {
        try {
            done(null, runAnalysis(that, source));
        }
        catch (e) {
            done(e);
        }
    }, 0);
};
