import { Plugin, Compiler } from "webpack";
import { MarkedOptions } from "marked";
import { TypeMetadata } from "./analysis/metadata";
/**
 * Storybook plugin that renders story metadata.
 */
export declare class StorybookPlugin implements Plugin {
    private _options;
    /**
     * Creates new instance of StorybookPlugin.
     * @param options Plugin options.
     */
    constructor(options?: StorybookPluginOptions);
    /**
     * Creates a loader needed for this plugin to work.
     */
    static loader(): string;
    metadata: {
        [path: string]: TypeMetadata;
    };
    currentRunMetadata: {
        [path: string]: TypeMetadata;
    };
    readonly options: StorybookPluginOptions;
    apply(compiler: Compiler): void;
    reset: () => void;
    private _setLoaderContext;
    private _saveAstMetadata;
}
/**
 * Storybook plugin options.
 */
export interface StorybookPluginOptions {
    /**
     * Path to `tsconfig.json` file.
     */
    tsConfigPath?: string;
    /**
     * Optional Git linking settings. Used to point story component to Git source.
     */
    gitLinking?: GitLinking;
    /**
     * Optional `marked` options.
     */
    markedOptions?: MarkedOptions;
}
/**
 * Git linking options.
 */
export interface GitLinking {
    /**
     * Path to local .git directory.
     */
    localGitDir: string;
    /**
     * Base URL of Git blob.
     */
    gitBlobUrl: string;
}
