"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var webpack_1 = require("webpack");
var copy_webpack_plugin_1 = require("copy-webpack-plugin");
var HtmlWebPackPlugin = require("html-webpack-plugin");
var PATH = require("path");
var FS = require("fs");
var plugin_1 = require("./plugin");
var markdown_1 = require("./markdown");
function baseConfig(angularConfig, _a) {
    var tsConfigPath = _a.tsConfigPath, configDir = _a.configDir;
    var markedOptions = markdown_1.markedLoaderOptions();
    var configFile = PATH.resolve(configDir, "./config");
    var configEntry = FS.existsSync(configFile + ".ts") ? configFile + ".ts" : configFile + ".js";
    return {
        context: angularConfig.context,
        entry: {
            preview: angularConfig.entry["polyfills"].concat([configEntry]),
            styles: angularConfig.entry["styles"]
        },
        output: {
            publicPath: ""
        },
        module: {
            rules: [
                {
                    test: /\.ts$/,
                    enforce: "pre",
                    use: plugin_1.StorybookPlugin.loader()
                }
            ].concat(getAngularRules(angularConfig, "html", "svg", "png", "css", "@angular"), [
                {
                    test: /\.md$/,
                    use: [
                        {
                            loader: require.resolve("raw-loader")
                        },
                        {
                            loader: require.resolve("markdown-loader"),
                            options: markedOptions
                        }
                    ]
                }
            ])
        },
        resolve: {
            modules: angularConfig.resolve.modules,
            extensions: [".ts", ".js"],
            alias: __assign({}, (angularConfig.resolve.alias || {}), { "@storybook/angular": PATH.resolve(__dirname, "../preview/api/core_api.js"), react: PATH.resolve(__dirname, "./react-stubs.js"), "react-dom": PATH.resolve(__dirname, "./react-stubs.js") })
        },
        resolveLoader: {
            modules: angularConfig.resolveLoader.modules
        },
        plugins: [
            angularConfig.plugins.find(function (p) { return p["copyWebpackPluginPatterns"]; }),
            new webpack_1.IgnorePlugin(/^\.\/locale$/, /moment$/),
            new copy_webpack_plugin_1.default([
                {
                    from: PATH.resolve(__dirname, "../public/index.html")
                }
            ]),
            new HtmlWebPackPlugin({
                template: PATH.resolve(__dirname, "../preview/iframe.html"),
                filename: "./iframe.html"
            }),
            new plugin_1.StorybookPlugin({
                tsConfigPath: tsConfigPath,
                gitLinking: {
                    gitBlobUrl: process.env["CG_GIT_URL"],
                    localGitDir: process.env["CG_GIT_DIR"] || PATH.resolve(configDir, "..")
                },
                markedOptions: markedOptions
            })
        ]
    };
}
exports.baseConfig = baseConfig;
function getAngularRules(angularConfig) {
    var ruleKeys = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        ruleKeys[_i - 1] = arguments[_i];
    }
    return angularConfig.module.rules.filter(function (r) {
        return ruleKeys.some(function (rk) { return r.test.toString().includes(rk); });
    });
}
